diff --git a/build/exe/doliwamp/doliwamp.iss b/build/exe/doliwamp/doliwamp.iss
index 7eba16e195e..7e94899455c 100644
--- a/build/exe/doliwamp/doliwamp.iss
+++ b/build/exe/doliwamp/doliwamp.iss
@@ -17,9 +17,9 @@
; ----- Change this -----
AppName=DoliWamp
; DoliWamp-x.x.x or DoliWamp-x.x.x-alpha or DoliWamp-x.x.x-beta or DoliWamp-x.x.x-rc or DoliWamp-x.x.x
-AppVerName=DoliWamp-3.6.0-alpha
+AppVerName=DoliWamp-3.6.0-beta
; DoliWamp-x.x x or DoliWamp-x.x.x-alpha or DoliWamp-x.x.x-beta or DoliWamp-x.x.x-rc or DoliWamp-x.x.x
-OutputBaseFilename=DoliWamp-3.6.0-alpha
+OutputBaseFilename=DoliWamp-3.6.0-beta
; ----- End of change
;OutputManifestFile=build\doliwampbuild.log
; Define full path from which all relative path are defined
diff --git a/htdocs/core/class/commonobject.class.php b/htdocs/core/class/commonobject.class.php
index 7f13f128541..0a44be050e7 100644
--- a/htdocs/core/class/commonobject.class.php
+++ b/htdocs/core/class/commonobject.class.php
@@ -3290,9 +3290,11 @@ abstract class CommonObject
* Add resources to the current object : add entry into llx_element_resources
*Need $this->element & $this->id
*
- * @param int $resource_id Resource id
+ * @param int $resource_id Resource id
* @param string $resource_element Resource element
- * @return int <=0 if KO, >0 if OK
+ * @param int $busy Busy or not
+ * @param int $mandatory Mandatory or not
+ * @return int <=0 if KO, >0 if OK
*/
function add_element_resource($resource_id,$resource_element,$busy=0,$mandatory=0)
{
@@ -3327,7 +3329,7 @@ abstract class CommonObject
return 0;
}
}
-
+
/**
* Delete a link to resource line
*
@@ -3339,12 +3341,12 @@ abstract class CommonObject
function delete_resource($rowid, $element, $notrigger=0)
{
global $user,$langs,$conf;
-
+
$error=0;
-
+
$sql = "DELETE FROM ".MAIN_DB_PREFIX."element_resources";
$sql.= " WHERE rowid =".$rowid;
-
+
dol_syslog(get_class($this)."::delete_resource sql=".$sql);
if ($this->db->query($sql))
{
@@ -3359,7 +3361,7 @@ abstract class CommonObject
}
// End call triggers
}
-
+
return 1;
}
else
diff --git a/htdocs/core/class/html.form.class.php b/htdocs/core/class/html.form.class.php
index 1de888a6f11..d3111d38a05 100644
--- a/htdocs/core/class/html.form.class.php
+++ b/htdocs/core/class/html.form.class.php
@@ -3264,7 +3264,7 @@ class Form
{
global $conf,$langs,$user;
- $langs->load_cache_currencies('');
+ $langs->loadCacheCurrencies('');
$out='';
diff --git a/htdocs/core/class/translate.class.php b/htdocs/core/class/translate.class.php
index a185433abef..a7cabd9468d 100644
--- a/htdocs/core/class/translate.class.php
+++ b/htdocs/core/class/translate.class.php
@@ -722,7 +722,7 @@ class Translate
if (function_exists("mb_convert_encoding"))
{
- $this->load_cache_currencies($forceloadall?'':$currency_code);
+ $this->loadCacheCurrencies($forceloadall?'':$currency_code);
if (isset($this->cache_currencies[$currency_code]) && ! empty($this->cache_currencies[$currency_code]['unicode']) && is_array($this->cache_currencies[$currency_code]['unicode']))
{
@@ -742,7 +742,7 @@ class Translate
* @param string $currency_code Get only currency. Get all if ''.
* @return int Nb of loaded lines, 0 if already loaded, <0 if KO
*/
- public function load_cache_currencies($currency_code)
+ public function loadCacheCurrencies($currency_code)
{
global $db;
@@ -754,7 +754,7 @@ class Translate
if (! empty($currency_code)) $sql.=" AND code_iso = '".$currency_code."'";
//$sql.= " ORDER BY code_iso ASC"; // Not required, a sort is done later
- dol_syslog(get_class($this).'::load_cache_currencies sql='.$sql, LOG_DEBUG);
+ dol_syslog(get_class($this).'::loadCacheCurrencies sql='.$sql, LOG_DEBUG);
$resql = $db->query($sql);
if ($resql)
{
diff --git a/htdocs/core/lib/resource.lib.php b/htdocs/core/lib/resource.lib.php
index c516485ed9d..e92d59dcac7 100644
--- a/htdocs/core/lib/resource.lib.php
+++ b/htdocs/core/lib/resource.lib.php
@@ -17,11 +17,17 @@
*/
/**
- * \file lib/resource.lib.php
+ * \file htdocs/core/lib/resource.lib.php
* \ingroup resource
* \brief This file is library for resource module
*/
+/**
+ * Prepare head for tabs
+ *
+ * @param Object $object Object
+ * @return array Array of head entries
+ */
function resourcePrepareHead($object)
{
global $langs, $conf, $user;
diff --git a/htdocs/core/modules/modResource.class.php b/htdocs/core/modules/modResource.class.php
index b391c6bb4af..26fe0b4bd31 100644
--- a/htdocs/core/modules/modResource.class.php
+++ b/htdocs/core/modules/modResource.class.php
@@ -61,7 +61,7 @@ class modResource extends DolibarrModules
// (where XXX is value of numeric property 'numero' of module)
$this->description = "Description of module Resource";
// Possible values for version are: 'development', 'experimental' or version
- $this->version = 'experimental';
+ $this->version = 'development';
// Key used in llx_const table to save module status enabled/disabled
// (where MYMODULE is value of property name of module in uppercase)
$this->const_name = 'MAIN_MODULE_' . strtoupper($this->name);
@@ -94,7 +94,7 @@ class modResource extends DolibarrModules
// Set this to relative path of css if module has its own css file
//'css' => '/resource/css/resource.css.php',
// Set here all hooks context managed by module
- 'hooks' => array('actioncard','actioncommdao','resource_card','element_resource')
+ // 'hooks' => array('actioncard','actioncommdao','resource_card','element_resource')
// Set here all workflow context managed by module
//'workflow' => array('order' => array('WORKFLOW_ORDER_AUTOCREATE_INVOICE'))
);
@@ -190,7 +190,7 @@ class modResource extends DolibarrModules
$this->rights[$r][3] = 0;
$this->rights[$r][4] = 'delete';
$r++;
-
+
$this->rights[$r][0] = 1101204;
$this->rights[$r][1] = 'Link resources';
$this->rights[$r][3] = 0;
@@ -225,7 +225,7 @@ class modResource extends DolibarrModules
'titre'=> 'MenuResourceIndex',
'mainmenu'=>'tools',
'leftmenu'=> 'resource',
- 'url'=> '/resource/list.php',
+ 'url'=> '/resource/list.php',
'langs'=> 'resource',
'position'=> 100,
'enabled'=> '1',
@@ -233,7 +233,7 @@ class modResource extends DolibarrModules
'user'=> 0
);
$r++;
-
+
$this->menu[$r++]=array(
'fk_menu'=>'fk_mainmenu=tools,fk_leftmenu=resource', //On utilise les ancres définis dans le menu parent déclaré au dessus
'type'=> 'left', // Toujours un menu gauche
diff --git a/htdocs/filefunc.inc.php b/htdocs/filefunc.inc.php
index d89f06993c2..bff0fa716f1 100644
--- a/htdocs/filefunc.inc.php
+++ b/htdocs/filefunc.inc.php
@@ -29,7 +29,7 @@
* \brief File that include conf.php file and commons lib like functions.lib.php
*/
-if (! defined('DOL_VERSION')) define('DOL_VERSION','3.6.0-alpha');
+if (! defined('DOL_VERSION')) define('DOL_VERSION','3.6.0-beta');
if (! defined('EURO')) define('EURO',chr(128));
// Define syslog constants
diff --git a/htdocs/resource/class/actions_resource.class.php b/htdocs/resource/class/actions_resource.class.php
index 8c2550fb549..8d233dea847 100644
--- a/htdocs/resource/class/actions_resource.class.php
+++ b/htdocs/resource/class/actions_resource.class.php
@@ -23,6 +23,7 @@
/**
* Actions class file for resources
*
+ * TODO Remove this class and replace a method into commonobject
*/
class ActionsResource
{
@@ -44,10 +45,12 @@ class ActionsResource
/**
* doActions for resource module
*
- * @param array $parameters parameters
- * @param Object $object object
- * @param string $action action
+ * @param array $parameters parameters
+ * @param Object &$object object
+ * @param string &$action action
+ * @return void
*/
+ /* Why a hook action ? TODO Remove this class and replace a method into commonobject
function doActions($parameters, &$object, &$action)
{
global $langs,$user;
@@ -60,9 +63,9 @@ class ActionsResource
$res = $object->fetch(GETPOST('id'));
if($res)
{
-
+
$result = $object->delete(GETPOST('id'));
-
+
if ($result >= 0)
{
setEventMessage($langs->trans('RessourceSuccessfullyDeleted'));
@@ -117,8 +120,8 @@ class ActionsResource
{
$res = $object->fetch(GETPOST('id'));
if($res)
- {
-
+ {
+
$result = $object->delete_resource(GETPOST('lineid'),GETPOST('element'));
if ($result >= 0)
@@ -131,7 +134,7 @@ class ActionsResource
setEventMessage($object->error,'errors');
}
}
- else
+ else
{
setEventMessage($object->error,'errors');
}
@@ -143,10 +146,10 @@ class ActionsResource
$res = $object->fetch_element_resource(GETPOST('lineid'));
if($res)
{
-
+
$object->busy = GETPOST('busy');
$object->mandatory = GETPOST('mandatory');
-
+
$result = $object->update_element_resource($user);
if ($result >= 0)
@@ -160,8 +163,6 @@ class ActionsResource
}
}
}
-
}
-
- }
+ }*/
}
diff --git a/test/soapui/Dolibarr-soapui-project.xml b/test/soapui/Dolibarr-soapui-project.xml
index 9d9e7890443..1ffd1ad0e3c 100755
--- a/test/soapui/Dolibarr-soapui-project.xml
+++ b/test/soapui/Dolibarr-soapui-project.xml
@@ -225,7 +225,7 @@
-]]>http://schemas.xmlsoap.org/wsdl/http://localhostdolibarr/dolibarrnew/webservices/server_invoice.phphttp://localhost/dolibarrnew/webservices/server_invoice.phpUTF-8http://localhost/dolibarrnew/webservices/server_invoice.php
+]]>http://schemas.xmlsoap.org/wsdl/http://localhostdolibarr/dolibarr_new/webservices/server_invoice.phphttp://localhost/dolibarrnew/webservices/server_invoice.phpUTF-8http://localhost/dolibarrnew/webservices/server_invoice.php
@@ -324,7 +324,7 @@
-]]>UTF-8http://localhostdolibarr/dolibarrnew/webservices/server_invoice.php
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
@@ -383,7 +383,7 @@
-]]>UTF-8http://localhostdolibarr/dolibarrnew/webservices/server_invoice.php
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
@@ -442,66 +442,132 @@
-]]>UTF-8http://localhostdolibarr/dolibarrnew/webservices/server_invoice.php
-
-
-
-
-
- ?
- ?
- ?
- ?
- ?
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
+
+
+
+ dolibarrkey
+ PRESTASHOP
+ admin
+ admin
+
-
-
- ?
- [?]
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
-
-
-
-
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
-
+
+ NFS0000000007
+ 30
+ 2014-04-23 15:59:24
+ 0
+ imported by Prestashop
+
+ 1
+
+
+ -
+ 0
+ Product
+ 66.05
+ 198.150000
+ 38.85
+ 237.000000
+ 19.600
+ 3
+ 1
+
+ -
+ 0
+ Product
+ 66.05
+ 132.100000
+ 25.9
+ 158.000000
+ 19.600
+ 2
+ 1
+
+ -
+ 0
+ Product
+ 1170.57
+ 1170.570000
+ 229.43
+ 1400.000000
+ 19.600
+ 1
+ 1
+
+ -
+ 0
+ Product
+ 25.04
+ 25.040000
+ 4.91
+ 29.950000
+ 19.600
+ 1
+ 1
+
+ -
+ 0
+ Product
+ 124.58
+ 124.580000
+ 24.42
+ 149.000000
+ 19.600
+ 1
+ 1
+
+ -
+ 1
+ Transport
+ 2.00
+ 2.00
+ 0.39
+ 2.39
+ 19.600
+ 1
+
+
-
-
-]]>UTF-8http://localhost/dolibarrnew/webservices/server_invoice.php
+
+
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
+
+
+
+ dolibarrkey
+ PRESTASHOP
+ admin
+ admin
+
+
+
+ WSTESTCREATEINVOICE1
+ 1
+ 2014-04-23 15:59:24
+ 0
+ Created from WS
+
+ 1
+
+
+ -
+ 0
+ Product
+ 66.05
+ 198.150000
+ 38.85
+ 237.000000
+ 19.600
+ 3
+ 1
+
+
+
+
+
+]]>UTF-8http://localhost/dolibarrnew/webservices/server_invoice.php
@@ -518,7 +584,7 @@
-]]>UTF-8http://localhostdolibarr/dolibarrnew/webservices/server_invoice.php
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
@@ -550,7 +616,7 @@
4
-]]>UTF-8http://localhostdolibarr/dolibarrnew/webservices/server_invoice.php
+]]>UTF-8http://localhostdolibarr/dolibarr_new/webservices/server_invoice.php
@@ -986,64 +1052,97 @@
-]]>http://schemas.xmlsoap.org/wsdl/http://localhost/dolibarr_new/webservices/server_productorservice.phphttp://localhostdolibarr/dolibarrnew/webservices/server_productorservice.phphttp://localhost/dolibarr/htdocs/webservices/server_productorservice.phphttp://localhost/dolibarr_new/webservices/server_productorservice.phpUTF-8http://localhost/dolibarr_new/webservices/server_productorservice.php
-
-
-
-
-
+]]>http://schemas.xmlsoap.org/wsdl/http://localhost/dolibarr_new/webservices/server_productorservice.phphttp://localhostdolibarr/dolibarrnew/webservices/server_productorservice.phphttp://localhost/dolibarr/htdocs/webservices/server_productorservice.phphttp://localhost/dolibarr_new/webservices/server_productorservice.phpUTF-8http://localhost/dolibarr_new/webservices/server_productorservice.php
+
+
+
dolibarrkey
- DEMO
+ PRESTASHOP
admin
admin
-
-
- ?
- [NewProductFromWS]
- ?
- 1
-
- This is a new product created from WS PHPUnit test case
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
- ?
-
- ?
- ?
-
-
-
- ?
- ?
- ?
- ?
-
-
-
-
-
-]]>UTF-8http://localhost/dolibarr_new/webservices/server_productorservice.php
+
+ NFS0000000007
+ 30
+ 2014-04-23 15:59:24
+ 0
+ imported by Prestashop
+
+ 1
+
+
+ -
+ 0
+ Product
+ 66.05
+ 198.150000
+ 38.85
+ 237.000000
+ 19.600
+ 3
+ 48
+
+ -
+ 0
+ Product
+ 66.05
+ 132.100000
+ 25.9
+ 158.000000
+ 19.600
+ 2
+ 50
+
+ -
+ 0
+ Product
+ 1170.57
+ 1170.570000
+ 229.43
+ 1400.000000
+ 19.600
+ 1
+ 51
+
+ -
+ 0
+ Product
+ 25.04
+ 25.040000
+ 4.91
+ 29.950000
+ 19.600
+ 1
+ 72
+
+ -
+ 0
+ Product
+ 124.58
+ 124.580000
+ 24.42
+ 149.000000
+ 19.600
+ 1
+ 46
+
+ -
+ 1
+ Transport
+ 2.00
+ 2.00
+ 0.39
+ 2.39
+ 19.600
+ 1
+
+
+
+
+
+
+]]>UTF-8http://localhost/dolibarr_new/webservices/server_productorservice.php
diff --git a/htdocs/contrat/class/contrat.class.php b/htdocs/contrat/class/contrat.class.php
index f5b158e2161..15fd88305d7 100644
--- a/htdocs/contrat/class/contrat.class.php
+++ b/htdocs/contrat/class/contrat.class.php
@@ -1151,11 +1151,11 @@ class Contrat extends CommonObject
$this->db->begin();
// Calcul du total TTC et de la TVA pour la ligne a partir de
// qty, pu, remise_percent et txtva
// TRES IMPORTANT: C'est au moment de l'insertion ligne qu'on doit stocker
// la part ht, tva et ttc, et ce au niveau de la ligne qui a son propre taux tva.
- $localtaxes_type=getLocalTaxesFromRate($txtva,0,$mysoc);
+ $localtaxes_type=getLocalTaxesFromRate($tvatx,0,$mysoc);
$tabprice=calcul_price_total($qty, $pu, $remise_percent, $tvatx, $localtaxtx1, $txlocaltaxtx2, 0, $price_base_type, $info_bits, 1, '', $localtaxes_type);
$total_ht = $tabprice[0];
@@ -1151,11 +1151,11 @@ class Contrat extends CommonObject
$this->db->begin();
// Calcul du total TTC et de la TVA pour la ligne a partir de
- // qty, pu, remise_percent et txtva
+ // qty, pu, remise_percent et tvatx
// TRES IMPORTANT: C'est au moment de l'insertion ligne qu'on doit stocker
// la part ht, tva et ttc, et ce au niveau de la ligne qui a son propre taux tva.